package com.autentia.tutorial.web.rest;

import java.util.List;

import javax.inject.Inject;

import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;

import com.autentia.tutorial.services.Provider;
import com.autentia.tutorial.services.ProviderStore;

@Controller
@RequestMapping("/provider")
public class ProviderController {

	private final ProviderStore providerStore;
	
	@Inject
	public ProviderController(ProviderStore providerStore) {
		this.providerStore = providerStore;
	}
	
	@RequestMapping(method=RequestMethod.GET)
	public String getCreateForm(Model model) {
		model.addAttribute(new Provider());
		return "provider/createForm";
	}

	@RequestMapping(value="/names", method=RequestMethod.GET)
	public @ResponseBody List<String> getProvidersNames() {
		return providerStore.getProvidersNames();
	}
	
	@RequestMapping(value="/{id}", method=RequestMethod.GET)
	public @ResponseBody Provider getProvider(@PathVariable Long id) {
		final Provider provider = providerStore.loadProvider(id);
		if (provider == null) {
			throw new ResourceNotFoundException(id);
		}
		return provider; 
	}

	@RequestMapping(value="/store", method=RequestMethod.POST)
	public @ResponseBody Long addProvider(@RequestBody Provider provider) {
		final Provider storedProvider = providerStore.sotreProvider(provider);
		return storedProvider.getId();
	}
	
	@RequestMapping(value="/test", method=RequestMethod.GET)
	public @ResponseBody String test() {
		return "Hola Mundo !!!";
	}

}
